from rest_framework.viewsets import ModelViewSet, ReadOnlyModelViewSet


class VersionedModelViewSet(ModelViewSet):
    """
    TODO: 优化异常处理和对应状态码
    """
    pass


class ReadOnlyVersionedModelViewSet(ReadOnlyModelViewSet):
    """
    TODO: 优化异常处理和对应状态码
    """
    pass
